.. _changes:
.. include:: ../../README.rst

Contents
========

.. toctree::
   :caption: pywatemsedem
   :maxdepth: 2

   Installation <installation>
   Module Reference <api/modules>

.. toctree::
   :caption: Getting started
   :maxdepth: 1

   Data processing<getting-started/api.ipynb>
   Calibrating WaTEM/SEDEM <getting-started/calibrate.ipynb>
   Processing rasters and vector <getting-started/geo.rst>
   User Choices <getting-started/userchoices.rst>
   IO <getting-started/io.rst>

.. toctree::
   :caption: Developer guide
   :maxdepth: 1

   Contributing <contributing>
   Authors <authors>
   Changelog <changelog>
   License <license>
   Code of conduct <codeofconduct>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _toctree: http://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
.. _reStructuredText: http://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
.. _references: http://www.sphinx-doc.org/en/stable/markup/inline.html
.. _Python domain syntax: http://sphinx-doc.org/domains.html#the-python-domain
.. _Sphinx: http://www.sphinx-doc.org/
.. _Python: http://docs.python.org/
.. _Numpy: http://docs.scipy.org/doc/numpy
.. _SciPy: http://docs.scipy.org/doc/scipy/reference/
.. _matplotlib: https://matplotlib.org/contents.html#
.. _Pandas: http://pandas.pydata.org/pandas-docs/stable
.. _Scikit-Learn: http://scikit-learn.org/stable
.. _autodoc: http://www.sphinx-doc.org/en/stable/ext/autodoc.html
.. _Google style: https://github.com/google/styleguide/blob/gh-pages/pyguide.md#38-comments-and-docstrings
.. _NumPy style: https://numpydoc.readthedocs.io/en/latest/format.html
.. _classical style: http://www.sphinx-doc.org/en/stable/domains.html#info-field-lists


Acknowledgements
================

Part of project is based on the `cookiecutter data science template <https://drivendata.github.io/cookiecutter-data-science>`_
